@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Type::Relationship;
 # ABSTRACT: Describes a relationship from a Neo4j graph
-$Neo4j::Driver::Type::Relationship::VERSION = '0.32';
+$Neo4j::Driver::Type::Relationship::VERSION = '0.33';
 
 use parent 'Neo4j::Types::Relationship';
 use overload '%{}' => \&_hash, fallback => 1;
@@ -127,7 +127,7 @@ Neo4j::Driver::Type::Relationship - Describes a relationship from a Neo4j graph
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 SYNOPSIS
 
@@ -168,9 +168,12 @@ L<Neo4j::Types::Relationship>.
 Return an ID for this relationship that is unique within
 a particular context, for example the current transaction.
 
-For relationships retrieved from S<Neo4j 5>, this method
-provides the new element ID string. For older Neo4j versions,
-this method provides the legacy numeric ID instead.
+This method provides the new element ID string introduced by
+S<Neo4j 5>. If the element ID is unavailable, for example with
+older Neo4j versions or with a L<Neo4j::Bolt> version that
+hasn't yet been updated for S<Neo4j 5>, this method provides
+the legacy numeric ID instead. Note that a numeric ID cannot
+successfully be used with C<elementId()> in Cypher expressions.
 
 Neo4j element IDs are not designed to be persistent. As such,
 if you want a public identity to use for your relationships,
@@ -216,9 +219,11 @@ See L<Neo4j::Types::Relationship/"properties">.
 
 Return an element ID for the node where this relationship starts.
 
-For relationships retrieved from S<Neo4j 5>, this method
-provides the new element ID string. For older Neo4j versions,
-this method provides the legacy numeric ID instead.
+This method provides the new element ID string introduced by
+S<Neo4j 5>. If the element ID is unavailable, for example with
+older Neo4j versions or with a L<Neo4j::Bolt> version that
+hasn't yet been updated for S<Neo4j 5>, this method provides
+the legacy numeric ID instead.
 
 =head2 start_id
 
@@ -238,9 +243,11 @@ be issued by this method in a future version of this driver.
 
 Return an element ID for the node where this relationship ends.
 
-For relationships retrieved from S<Neo4j 5>, this method
-provides the new element ID string. For older Neo4j versions,
-this method provides the legacy numeric ID instead.
+This method provides the new element ID string introduced by
+S<Neo4j 5>. If the element ID is unavailable, for example with
+older Neo4j versions or with a L<Neo4j::Bolt> version that
+hasn't yet been updated for S<Neo4j 5>, this method provides
+the legacy numeric ID instead.
 
 =head2 end_id
 
